summaryrefslogtreecommitdiffstats
path: root/src/H5FDs3comms.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5FDs3comms.c')
-rw-r--r--src/H5FDs3comms.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/H5FDs3comms.c b/src/H5FDs3comms.c
index c088fca..5d958b5 100644
--- a/src/H5FDs3comms.c
+++ b/src/H5FDs3comms.c
@@ -955,11 +955,11 @@ H5FD_s3comms_s3r_getsize(s3r_t *handle)
*/
*end = '\0';
- content_length = HDstrtoumax((const char *)start, NULL, 0);
+ content_length = strtoumax((const char *)start, NULL, 0);
if (UINTMAX_MAX > SIZE_MAX && content_length > SIZE_MAX)
HGOTO_ERROR(H5E_ARGS, H5E_OVERFLOW, FAIL, "content_length overflows size_t");
- if (content_length == 0 || errno == ERANGE) /* errno set by HDstrtoumax*/
+ if (content_length == 0 || errno == ERANGE) /* errno set by strtoumax*/
HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL,
"could not convert found \"Content-Length\" response (\"%s\")",
start); /* range is null-terminated, remember */